@@ -8,6 +8,9 @@ def prepare_table(table, converters=None):
 
 
 def text_table(table, spacing=2):
+    if not table:
+        return ()
+
     columns_sizes = [0] * len(table[0])
 
     for row in table:
